summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteonlinestatus.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteonlinestatus.h')
-rw-r--r--kopete/libkopete/kopeteonlinestatus.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/libkopete/kopeteonlinestatus.h b/kopete/libkopete/kopeteonlinestatus.h
index 5349677d..34f0bc9c 100644
--- a/kopete/libkopete/kopeteonlinestatus.h
+++ b/kopete/libkopete/kopeteonlinestatus.h
@@ -1,5 +1,5 @@
/*
- kopeteonlinestatus.h - Kopete Online Status
+ kopeteonlinestatus.h - Kopete Online tqStatus
Copyright (c) 2003 by Martijn Klingens <klingens@kde.org>
Copyright (c) 2003 by Duncan Mac-Vicar Prett <duncan@kde.org>
@@ -128,7 +128,7 @@ public:
* Any internal status value > 0x80000000 is reserved for internal
* libkopete use. This enumeration lists the currently known values.
*/
- enum ReservedInternalStatus
+ enum ReservedInternaltqStatus
{
/**
* The account this contact belongs to is offline. Used with
@@ -202,7 +202,7 @@ public:
* This status is usually a lot more fine-grained than the status as used
* by libkopete and should be unique per protocol.
* @param overlayIcon is a string returning the name of the status icon to be
* used by the KDE icon loader. (Status whiwh doesn't have icon to overlay like
* Online and Offline should use TQString() as icon string)
* @param description is a description in e.g. tooltips.
* @param caption is the text of the action in the menu
@@ -202,7 +202,7 @@ public:
* by libkopete and should be unique per protocol.
* @param overlayIcon is a string returning the name of the status icon to be
- * used by the KDE icon loader. (Status whiwh doesn't have icon to overlay like
+ * used by the KDE icon loader. (tqStatus whiwh doesn't have icon to overlay like
* Online and Offline should use TQString() as icon string)
* @param description is a description in e.g. tooltips.